/** @jsx dom */
import dom from 'magic-virtual-element';
import Swipe from 'swipe';

const propTypes = {
	class: {
		type: 'string'
	},
	duration: {
		type: 'number'
	},
	fastThreshold: {
		type: 'number'
	},
	interval: {
		type: 'number'
	},
	onChange: {
		type: 'function'
	},
	threshold: {
		type: 'number'
	}
};

function afterMount({props}, el) {
	const {duration, fastThreshold, interval, onChange, threshold} = props;
	const swipe = new Swipe(el);

	swipe.on('show', (i, el) => {
		if (onChange) {
			onChange(el, i);
		}
	});

	if (typeof duration === 'number') {
		swipe.duration(duration);
	}

	if (typeof fastThreshold === 'number') {
		swipe.fastThreshold(fastThreshold);
	}

	if (typeof interval === 'number') {
		swipe.interval(interval);
	}

	if (typeof threshold === 'number') {
		swipe.threshold(threshold);
	}

	swipe.play();
}

function render({props}) {
	const {children} = props;

	return (
		<div class={['Carousel', props.class]}>
			<div>{children}</div>
		</div>
	);
}

export default {afterMount, propTypes, render};
